@@ -13,10 +13,12 @@ from data_browser.query import (
     DateTimeType,
     DateType,
     MonthType,
+    NumberChoiceType,
     NumberType,
     Query,
     QueryField,
     QueryFilter,
+    StringChoiceType,
     StringType,
     WeekDayType,
     YearType,
@@ -411,3 +413,13 @@ class TestBooleanType:
 
     def test_default_lookup(self):
         assert BooleanType.default_lookup == "equals"
+
+
+class TestStringChoiceType:
+    def test_format(self):
+        assert StringChoiceType.format("b", [("a", "A"), ("b", "B"), ("c", "C")]) == "B"
+
+
+class TestNumberChoiceType:
+    def test_format(self):
+        assert NumberChoiceType.format(2, [(1, "A"), (2, "B"), (3, "C")]) == "B"
